Module grab.error — Grab 0.6 documentation

# Module grab.error

Custom exception classes for Grab.

class grab.error.GrabError

  All custom Grab exception should be children of that class.

class grab.error.GrabNetworkError(*args, **kwargs)

  Raises in case of network error.

class grab.error.GrabTimeoutError(*args, **kwargs)

  Raises when configured time is outed for the request.

  In curl transport it is CURLE_OPERATION_TIMEDOUT (28)

class grab.error.DataNotFound

class grab.error.GrabMisuseError

  Indicates incorrect usage of grab API.

class grab.error.GrabConnectionError(*args, **kwargs)

  Raised when it is not possible to establish network connection.

  In curl transport it is CURLE_COULDNT_CONNECT (7)

class grab.error.GrabAuthError

  Raised when remote server denies authentication credentials.

  In curl transport it is CURLE_COULDNT_CONNECT (67)

class grab.error.GrabTooManyRedirectsError

  Raised when Grab reached max. allowd number of redirects for one request.

class grab.error.GrabInvalidUrl

  Raised when Grab have no idea how to handle the URL or when some error occurred while normalizing URL e.g. IDN processing.

class grab.util.warning.GrabDeprecationWarning

  Warning category used in Grab to generate warning messages.